.. code-block:: bash

	Usage: cli [OPTIONS] COMMAND [ARGS]...
	
	  Nessie cli tool.
	
	  Interact with Nessie branches and tables via the command line
	
	Options:
	  --json           write output in json format.
	  -v, --verbose    Verbose output.
	  --endpoint TEXT  Optional endpoint, if different from config file.
	  --version
	  --help           Show this message and exit.
	
	Commands:
	  branch       Branch operations.
	  cherry-pick  Transplant HASHES onto current branch.
	  config       Set and view config.
	  contents     Contents operations.
	  log          Show commit log.
	  merge        Merge BRANCH into current branch.
	  remote       Set and view remote endpoint.
	  tag          Tag operations.
	
	

